@@ -130,9 +130,9 @@ class Hello
 
   def dregx: () -> ::Regexp
 
-  def t: () -> ::TrueClass
+  def t: () -> true
 
-  def f: () -> ::FalseClass
+  def f: () -> false
 
   def n: () -> nil
 
@@ -561,6 +561,7 @@ end
     rb = <<-EOR
 module Foo
   VERSION = '0.1.1'
+  FROZEN = 'str'.freeze
   ::Hello::World = :foo
 end
     EOR
@@ -569,9 +570,11 @@ end
 
     assert_write parser.decls, <<-EOF
 module Foo
-  VERSION: ::String
+  VERSION: "0.1.1"
 
-  ::Hello::World: ::Symbol
+  FROZEN: "str"
+
+  ::Hello::World: :foo
 end
     EOF
   end
@@ -615,21 +618,21 @@ H = { id: 123 }
     parser.parse(rb)
 
     assert_write parser.decls, <<-EOF
-A: ::Integer
+A: 1
 
 B: ::Float
 
 C: ::String
 
-D: ::Symbol
+D: :hello
 
-E: untyped?
+E: nil
 
-F: bool
+F: false
 
-G: ::Array[untyped]
+G: ::Array[1 | 2 | 3]
 
-H: ::Hash[untyped, untyped]
+H: { id: 123 }
     EOF
   end
 
@@ -751,6 +754,32 @@ end
     RBS
   end
 
+  def test_calling_class_method_from_instance
+    parser = RB.new
+
+    rb = <<~'RUBY'
+class HelloWorld
+  def self.world(str)
+    str + 'world'
+  end
+
+  def hello
+    self.class.world('hello')
+  end
+end
+    RUBY
+
+    parser.parse(rb)
+
+    assert_write parser.decls, <<~RBS
+class HelloWorld
+  def self.world: (untyped str) -> untyped
+
+  def hello: () -> untyped
+end
+    RBS
+  end
+
   if RUBY_VERSION >= '2.7'
     def test_argument_forwarding
       parser = RB.new
